aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorluigi1111 <luigi1111w@gmail.com>2019-02-22 11:30:58 -0600
committerluigi1111 <luigi1111w@gmail.com>2019-02-22 11:30:58 -0600
commitc2889c2b8173dda1e4fe50478c8d56ac00f2d255 (patch)
treed7ba6e21f470a56d88fbe9be9ed8a7d068910c59 /src
parent333f4aaf83bd64de02b07a56d86bbf90363e403b (diff)
parentc6107d8376244560068184cbfafd38d3b2f536b8 (diff)
downloadmonzero-gui-c2889c2b8173dda1e4fe50478c8d56ac00f2d255.tar.gz
monzero-gui-c2889c2b8173dda1e4fe50478c8d56ac00f2d255.tar.xz
monzero-gui-c2889c2b8173dda1e4fe50478c8d56ac00f2d255.zip
Merge pull request #1909
f329a71 Wizard redesign (xmrdsc) c6107d8 wizard: allow calendar date for restoration height (mmbyday)
Diffstat (limited to 'src')
-rw-r--r--src/daemon/DaemonManager.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/daemon/DaemonManager.cpp b/src/daemon/DaemonManager.cpp
index 09507a4a..a70f551b 100644
--- a/src/daemon/DaemonManager.cpp
+++ b/src/daemon/DaemonManager.cpp
@@ -275,9 +275,9 @@ QVariantMap DaemonManager::validateDataDir(const QString &dataDir) const
valid = false;
}
// Make sure there is 20GB storage available
storageAvailable = storage.bytesAvailable()/1000/1000/1000;
- if (storageAvailable < 20) {
+ if (storageAvailable < 75) {
valid = false;
}
} else {
@@ -275,9 +275,9 @@ QVariantMap DaemonManager::validateDataDir(const QString &dataDir) const
valid = false;
}
- // Make sure there is 20GB storage available
+ // Make sure there is 75GB storage available
storageAvailable = storage.bytesAvailable()/1000/1000/1000;